package com.ruoyi.oa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.oa.mapper.CmcProjectWorkMapper;
import com.ruoyi.oa.domain.CmcProjectWork;
import com.ruoyi.oa.service.ICmcProjectWorkService;

/**
 * cmc项目内容Service业务层处理
 * 
 * @author cmc
 * @date 2024-02-28
 */
@Service
public class CmcProjectWorkServiceImpl implements ICmcProjectWorkService 
{
    @Autowired
    private CmcProjectWorkMapper cmcProjectWorkMapper;

    /**
     * 查询cmc项目内容
     * 
     * @param projectId cmc项目id
     * @return cmc项目内容集合
     */
    @Override
    public List<CmcProjectWork> selectCmcProjectWorkListByProjectId(String projectId)
    {
        return cmcProjectWorkMapper.selectCmcProjectWorkListByProjectId(projectId);
    }

    /**
     * 查询cmc项目内容列表
     * 
     * @param cmcProjectWork cmc项目内容
     * @return cmc项目内容
     */
    @Override
    public List<CmcProjectWork> selectCmcProjectWorkList(CmcProjectWork cmcProjectWork)
    {
        return cmcProjectWorkMapper.selectCmcProjectWorkList(cmcProjectWork);
    }

    /**
     * 新增cmc项目内容
     * 
     * @param cmcProjectWork cmc项目内容
     * @return 结果
     */
    @Override
    public int insertCmcProjectWork(CmcProjectWork cmcProjectWork)
    {
        return cmcProjectWorkMapper.insertCmcProjectWork(cmcProjectWork);
    }

    /**
     * 修改cmc项目内容
     * 
     * @param cmcProjectWork cmc项目内容
     * @return 结果
     */
    @Override
    public int updateCmcProjectWork(CmcProjectWork cmcProjectWork)
    {
        return cmcProjectWorkMapper.updateCmcProjectWork(cmcProjectWork);
    }

    /**
     * 批量删除cmc项目内容
     * 
     * @param workIds 需要删除的cmc项目内容主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectWorkByProjectIds(String[] workIds)
    {
        return cmcProjectWorkMapper.deleteCmcProjectWorkByProjectIds(workIds);
    }

    /**
     * 删除cmc项目内容信息
     * 
     * @param projectId cmc项目内容主键
     * @return 结果
     */
    @Override
    public int deleteCmcProjectWorkByProjectId(String projectId)
    {
        return cmcProjectWorkMapper.deleteCmcProjectWorkByProjectId(projectId);
    }
}
